@@ -14,13 +14,15 @@ import (
 )
 
 // delay checking for at least 5 minutes when rate limit is exceeded
-var rateLimitRetryMin = time.Minute * 5
-var defaultMediaTypes = []string{
-	mediatype.Docker2Manifest,
-	mediatype.Docker2ManifestList,
-	mediatype.OCI1Manifest,
-	mediatype.OCI1ManifestList,
-}
+var (
+	rateLimitRetryMin = time.Minute * 5
+	defaultMediaTypes = []string{
+		mediatype.Docker2Manifest,
+		mediatype.Docker2ManifestList,
+		mediatype.OCI1Manifest,
+		mediatype.OCI1ManifestList,
+	}
+)
 
 // Config is parsed configuration file for regsync
 type Config struct {
@@ -66,8 +68,9 @@ type ConfigSync struct {
 	Source          string                 `yaml:"source" json:"source"`
 	Target          string                 `yaml:"target" json:"target"`
 	Type            string                 `yaml:"type" json:"type"`
-	Tags            AllowDeny              `yaml:"tags" json:"tags"`
-	Repos           AllowDeny              `yaml:"repos" json:"repos"`
+	Tags            TagAllowDeny           `yaml:"tags" json:"tags"`
+	TagSets         []TagAllowDeny         `yaml:"tagSets" json:"tagSets"`
+	Repos           RepoAllowDeny          `yaml:"repos" json:"repos"`
 	DigestTags      *bool                  `yaml:"digestTags" json:"digestTags"`
 	Referrers       *bool                  `yaml:"referrers" json:"referrers"`
 	ReferrerFilters []ConfigReferrerFilter `yaml:"referrerFilters" json:"referrerFilters"`
@@ -86,12 +89,19 @@ type ConfigSync struct {
 	Hooks           ConfigHooks            `yaml:"hooks" json:"hooks"`
 }
 
-// AllowDeny is an allow and deny list of regex strings
-type AllowDeny struct {
+// RepoAllowDeny is an allow and deny list of regex strings for repository names
+type RepoAllowDeny struct {
 	Allow []string `yaml:"allow" json:"allow"`
 	Deny  []string `yaml:"deny" json:"deny"`
 }
 
+// TagAllowDeny is an allow and deny list of regex strings for tags, with optional semver version range support
+type TagAllowDeny struct {
+	Allow       []string `yaml:"allow" json:"allow"`
+	Deny        []string `yaml:"deny" json:"deny"`
+	SemverRange []string `yaml:"semverRange,omitempty" json:"semverRange,omitempty"` // array of semver constraints, e.g., [">=1.0.0 <2.0.0", ">=4.0.0"]
+}
+
 type ConfigReferrerFilter struct {
 	ArtifactType string            `yaml:"artifactType" json:"artifactType"`
 	Annotations  map[string]string `yaml:"annotations" json:"annotations"`
